Basic data handling example
==============================

The code
--------
.. literalinclude:: basic_data_handling.py

The generated files
-------------------
I_CV_BE.pdf

.. figure:: /_static/I_CV_BE.pdf.png

.. literalinclude:: /_static/I_CV_BE.tex
    :language: latex
    :linenos:
    :caption: I_CV_BE.tex
